#include "events.hpp"
#include "repair.hpp"
#include "machine.hpp"

#include <iostream>

using namespace eosim::core;



EndWork::EndWork(eosim::core::Model& model): BEvent(endW, model) {}

EndWork::~EndWork() {}

void EndWork::eventRoutine(eosim::core::Entity* who) {
	Repair& r = (Repair&)owner;
	r.toRemove.push(who);
	std::cout << r.getSimTime() << "\tSe rompio la maquina " << ((Machine*)who)->getNumber() << '\n';
}


StartRemove::StartRemove(eosim::core::Model& model): CEvent(model) {}

StartRemove::~StartRemove() {}

void StartRemove::eventRoutine() {
	Repair& r = (Repair&)owner;
	for(;!r.toRemove.empty() && r.mechanics.isAvailable(1);) {
		r.mechanics.acquire(1);
		Machine* m = (Machine*)r.toRemove.pop();
		double time = r.removal.sample();
		for(; time < 0; time = r.removal.sample());
		r.schedule(time, m, endRv);
		std::cout << r.getSimTime() << "\tSe comenzo a remover las piezas de la maquina " << m->getNumber() << '\n';
	}
}


EndRemove::EndRemove(eosim::core::Model& model): BEvent(endRv, model) {}

EndRemove::~EndRemove() {}

void EndRemove::eventRoutine(eosim::core::Entity* who) {
	Repair& r = (Repair&)owner;
	r.toRepair.push(who);
	std::cout << r.getSimTime() << "\tSe termino de remover las piezas de la maquina " << ((Machine*)who)->getNumber() << '\n';
}


StartRepair::StartRepair(eosim::core::Model& model): CEvent(model)  {}

StartRepair::~StartRepair() {}

void StartRepair::eventRoutine() {
	Repair& r = (Repair&)owner;
	for(;!r.toRepair.empty() && r.equipment.isAvailable(1);) {
		r.equipment.acquire(1);
		Machine* m = (Machine*)r.toRepair.pop();
		double time = r.repair.sample();
		for(; time < 0; time = r.repair.sample());
		r.schedule(time, m, endRp);
		std::cout << r.getSimTime() << "\tSe comenzo a reparar la maquina " << m->getNumber() << '\n';
	}
}


EndRepair::EndRepair(eosim::core::Model& model): BEvent(endRp, model) {}

EndRepair::~EndRepair() {}

void EndRepair::eventRoutine(eosim::core::Entity* who) {
	Repair& r = (Repair&)owner;
	r.mechanics.returnBin(1);
	r.equipment.returnBin(1);
	r.schedule(r.breakDown.sample(), who, endW);
	std::cout << r.getSimTime() << "\tSe termino de reparar la maquina " << ((Machine*)who)->getNumber() << '\n';
}
