#ifndef BCALENDAR_HPP_
#define BCALENDAR_HPP_

#include <eosim/core/entity.hpp>
#include <eosim/utils/entityqueueordered.hpp>

/** \ingroup simuling_group
 * \@{
*/
/** \class eosim::core::BCalendar include\eosim\core\bcalendar.hpp <eosim/core/bcalendar.hpp>
 * \author Sebastin Alaggia
 * \version 1.0.1
 * \date    2005
 * \brief  B Events Calendar
 * <p>This class handles the B Events Calendar. The class main responsibility is to schedule entities for a
 * certain time to a certain bounded event. It also handles the simulation time.</p>
*/



namespace eosim {

namespace core {

	class BCalendar {
	private:
        double simTime, endSim;
        utils::EntityQueueOrdered ents;
	public:
		/**
		* \brief The constructor creates an empty BCalendar ready to operate.
		*/
		BCalendar ();
		/**
		* \brief The destructor deletes all the entities scheduled.
		*/
		~BCalendar ();
		/**
		* \brief This operation performs both A phase and B phase.
		*/
		void bPhase ();
		/**
		* \brief This operation returns true if the simulation is terminated.
		*/
		bool isStopped();
		/**
		* \brief This operation schedules who at the simulations actual time plus offset. It is assumed that who knows to which event is scheduled.
		*/
		void schedule (double offset, Entity* who);
		/**
		* \brief This operation sets the simulations end time. All simulations starts at 0.
		*/
		void setEndTime (double when);
		/**
		* \brief This operation returns the simulations actual time.
		*/
        double getSimTime();
	};
	
}

}

/**
 * \@}
*/

#endif

