#ifndef RENEWABLE_HPP_
#define RENEWABLE_HPP_

#include <eosim/core/bin.hpp>

/** \class eosim::core::Renewable include\eosim\core\renewable.hpp <eosim/core/renewable.hpp>
 *  \author Sebastin Alaggia
 *  \version 1.0.1
 *  \date    2005
 *  \brief  Renewable Bin
 
 * This class represent bins which are renewable, like chairs. This kind of bins are returned after they are used. So you can use them and return them after used. It inherits the acquire operation from its parent class, Bin.
*/




namespace eosim {

namespace core {

	class Renewable: public Bin {
	private:
		double max;
	public:
		/**
		* \brief The constructor creates a Renewable bin with quantity units and max capacity. If quantity is greater or equal than max and max is less or equal than zero, the simulation aborts immediately displaying an error message. 
		*/
		Renewable (double cuantity, double max);
		/**
		* \brief The destructor of Renewable.
		*/
		~Renewable ();
		/**
		* \brief This operation return amount units to the bin.
		*/
		void returnBin (double amount);	
		/**
		* \brief This operation returns the maximum capacity of the bin.
		*/
		double getMax();
	};
	
}

}

#endif

