#ifndef DISTMANAGER_HPP_
#define DISTMANAGER_HPP_

#include <eosim/dist/numbergenerator.hpp>
#include <eosim/utils/distvector.hpp>

/** \ingroup simuling_group
 * \@{
*/
/** \class eosim::dist::DistManager include\eosim\dist\distmanager.hpp <eosim/dist/distmanager.hpp>
 *  \author Sebastin Alaggia
 *  \version 1.0.1
 *  \date    2005
 *  \brief  Distribution Manager
 
 * This class handles a set of distributions. Its main responsibility is to perform operations to the whole set. It contains a seed generator to assign new seeds for the distributions registered.
*/


namespace eosim {
	
namespace dist {

	class DistManager {
	private:
		NumberGenerator* seedGenerator;
		utils::DistVector dVect;
	public:
		/**
		* \brief The constructor creates an empty DistManager with a seed generator of type seedGenerator.
		*/
		DistManager (GenType seedGenerator);
		/**
		* \brief The destructor of DistManager.
		*/
		~DistManager ();
		/**
		* \brief This operation sets a new seed to every distribution registered.
		*/
		void setSeed (unsigned long seed);
		/**
		* \brief This operation register d in the DistManager.
		*/
		void registerDist (Distribution* d);
	};
	
}

}

/**
 * \@}
*/

#endif

