#ifndef HISTOGRAM_HPP_
#define HISTOGRAM_HPP_

#include <string>
#include <map>
#include <utility>


/** \ingroup statics_group
 * \@{
*/
/** \class eosim::statics::Histogram include\eosim\statics\histogram.hpp <eosim/statics/histogram.hpp>
 *  \author Sebastin Alaggia
 *  \version 1.1.0
 *  \date    2005
 *  \brief  Abstract Histogram

 * <p>This is the parent class of all Histograms. It contains the basics operations of all histograms but you 
 * cant use it directly. Histograms store punctual values, but the pair (x1, y1) is logged and then the pair 
 * (x1, y2) is logged the histogram record the pair (x1, y1 + y2).</p>
*/


namespace eosim {

namespace core {
    class Model;
}

namespace statics {

    class Histogram {
    protected:
        double count,total,sosq;
        std::map< double, double > cell;
		std::pair< double, double > min;
		std::pair< double, double > max;
        std::string name;
        Histogram(std::string name);
		/**
		* \brief This is an auxiliary operation used to print histograms.
		
		* Basically the operations Histogram::table and Histogram::print are wrappers for this operation.
		*/
        std::string printH(unsigned int cantCell, bool graphic);
		/**
		* \brief This operations register x and y in the histogram. 
		*/
        void log(double x, double y);
    public:
		/**
		* \brief The destructor of Histogram.
		*/
        virtual ~Histogram();
		/**
		* \brief This operation erases every value registered in the histogram.
		*/
        void reset();
		/**
		* \brief This operation prints the histogram in the standard output. cantCell indicates how many bars have you histogram.
		*/
        void print(unsigned int cantCell);
		/**
		* \brief This operation prints the histogram in path file. cantCell indicates how many bars have you histogram.
		*/
        void print(unsigned int cantCell, const char* path);
		/**
		* \brief This operation prints a table with the values stored in the histogram in the standard output . cantCell indicates how many rows have you table.
		*/
        void table(unsigned int cantCell);
		/**
		* \brief This operation prints a table with the values stored in the histogram in path file.
		*/
        void table(unsigned int cantCell, const char* path);
		/**
		 * \brief This operation returns 1 if the histogram is empty. 
		*/
        bool empty();
		/**
		* \brief This operation returns the variance registered in the histogram.
		*/
        double getVariance();
		/**
		* \brief This operation returns the mean value registered in the histogram.
		*/
        double getMean();
		/**
		* \brief This operation returns the histograms name.
		*/
        std::string getName();
    };

}

}

/**
 * \@}
*/

#endif

