#ifndef TIMESERIES_HPP_
#define TIMESERIES_HPP_

#include <eosim/statics/histogram.hpp>
#include <eosim/core/model.hpp>

/** \ingroup statics_group
 * \@{
*/
/** \class eosim::statics::TimeSeries include\eosim\statics\timeseries.hpp <eosim/statics/timeseries.hpp>
 *  \author Sebastin Alaggia
 *  \version 1.1.0
 *  \date    2005
 *  \brief  Time Series Histogram
 
 * This kind of histogram shows the trends in response variables over time.
 * Basically it defines a <b>time vs. variable</b> chart (which match the evolution of the variable over time).
*/


namespace eosim {

namespace statics {

	class TimeSeries: public Histogram {
	private:
		core::Model &m;
	public:
		/**
		* \brief The constructor of TimeSeries; the kind of histogram is appended at the end of the name.
		* The model passed as an argument is the one which will be used to get the time values needed to log data in this histograms.
		*/
		TimeSeries(std::string name, core::Model &m);
		/**
		* \brief This operation log a value in the histogram.
		*/
		void log(double value);
	};

}

}

/**
 * \@}
*/

#endif

