#ifndef BEVENTMAP_HPP_
#define BEVENTMAP_HPP_

#include <eosim/core/bevent.hpp>
#include <map>
#include <string>

/** \ingroup utils_group
 * \@{
*/
/** \class eosim::utils::BEventMap include\eosim\utils\beventmap.hpp <eosim/utils/beventmap.hpp>
 *  \author Sebastin Alaggia
 *  \version 1.0.1
 *  \date    2005
 *  \brief   Mapping of B Events
 
 * This container stores BEvents, using their name as key. It is used by Model to register BEvent.
*/


namespace eosim {

namespace utils {

	class BEventMap {
	private:
		std::map<std::string, core::BEvent*> elems;
	public:
		/**
		* \brief The constructor creates an empty BEventMap.
		*/
		BEventMap ();
		/**
		* \brief The destructor of BEventMap.
		*/
		~BEventMap ();
		/**
		* \brief This operation adds elem to the map.
		*/
		void put (core::BEvent* elem);
		/**
		* \brief This operation remove the element whose name is key.
		*/
        void remove (std::string key);
		/**
		* \brief This operation finds the BEvent whose name is key.
		*/
        core::BEvent* operator[] (std::string key);
		/**
		* \brief This operation returns the size of the map.
		*/
		unsigned int size();	
	};

}

}

#endif

