#ifndef CEVENTVECTOR_HPP_
#define CEVENTVECTOR_HPP_

#include <eosim/core/cevent.hpp>
#include <vector>

/** \ingroup utils_group
 * \@{
*/
/** \class eosim::utils::CEventVector include\eosim\utils\ceventvector.hpp <eosim/utils/ceventvector.hpp>
 *  \author Sebastin Alaggia
 *  \version 1.0.1
 *  \date    2005
 *  \brief   Vector of C Events
 
 * This container stores CEvents in a vector. It is used by CCalendar to register CEvent.
*/


namespace eosim {

namespace utils {

	class CEventVector {
	private:
		std::vector<core::CEvent*> elems;
	public:
		/**
		* \brief The constructor creates an empty CEventVector.
		*/
		CEventVector ();
		/**
		* \brief The destructor of CEventVector. This operation doesnt delete any CEvents stored
		*/
		~CEventVector ();
		/**
		* \brief This operation adds elem at the end of the vector.
		*/
		void push (core::CEvent* elem);
		/**
		* \brief This operation remove the element whose position in the vector is i.
		*/
        void remove (unsigned i);
		/**
		* \brief This operation returns the CEvent whose position in the vector is i.
		* \note The use of this operation is either cVect[i] or cVect.operator[](i).
		*/
        core::CEvent* operator[] (unsigned int i);
		/**
		* \brief This operation returns the size of the vector.
		*/
		unsigned int size();	
	};
}

}

#endif

