#ifndef DISTVECTOR_HPP_
#define DISTVECTOR_HPP_

#include <eosim/dist/distribution.hpp>
#include <vector>

/** \ingroup utils_group
 * \@{
*/
/** \class eosim::utils::DistVector include\eosim\utils\distvector.hpp <eosim/utils/distvector.hpp>
 *  \author Sebastin Alaggia
 *  \version 1.0.1
 *  \date    2005
 *  \brief   Vector of Distributions
 
 * This container stores Distributions in a vector. It is used by DistManager to register Distributions.
*/



namespace eosim {
	
namespace utils {

	class DistVector {
	private:
		std::vector<dist::Distribution*> elems;
	public:
		/**
		* \brief The constructor creates an empty DistVector.
		*/
		DistVector ();
		/**
		* \brief The destructor of DistVector. This operation doesnt delete any Distributions stored
		*/
		~DistVector ();
		/**
		* \brief This operation adds elem at the end of the vector.
		*/
		void push (dist::Distribution* elem);
		/**
		* \brief This operation remove the element whose position in the vector is i.
		*/
        void remove (unsigned int i);
		/**
		* \brief This operation returns the Distribution whose position in the vector is i.
		*/
        dist::Distribution*& operator[] (unsigned int i);
		/**
		* \brief This operation returns the size of the vector.
		*/
		unsigned int size();	
	};
}

}

#endif

