#include <eosim/core/bcalendar.hpp>

using namespace eosim::core;
using namespace eosim::utils;


class ClockComp: public EntityComp {
public:
    ClockComp() {}
    ~ClockComp() {}
    bool compare (Entity* e1, Entity* e2) { return e1->getClock() < e2->getClock(); }
    
};

ClockComp c;

BCalendar::BCalendar ():  simTime(0), endSim(0), ents(EntityQueueOrdered(&c)) {
}

BCalendar::~BCalendar () {
/**
* \warning  It is assumed that all the entities had been created dynamically, so every entity stored is deleted.
*/
}

void BCalendar::bPhase () {
	/**
	* First, the simulation time is advanced to the time of the first scheduled event.
	*/
	simTime = ents[0]->getClock();
	/**
	*  Then BCalendar process all events which are scheduled at the actual simulation time.
	*/
    for (; simTime <= endSim && !ents.empty() && ents[0]->getClock() == simTime;) {
        Entity* temp = ents.pop();
        temp->processEvent();
    }    
}

bool BCalendar::isStopped() {
	return simTime <= endSim && !ents.empty();
}

void BCalendar::schedule (double offset, Entity* who) {
	who->setClock(simTime + offset);
    ents.push(who);
}

void BCalendar::setEndTime (double when) {
	endSim = when;
}

double BCalendar::getSimTime() {
	return simTime;
}

