#include <eosim/core/renewable.hpp>
#include <cassert>

using namespace eosim::core;


Renewable::Renewable(double quantity, double max): Bin(quantity), max(max) {
	/**
	* \warning The quantity must be less or equal than max, and max must be greater or equal than zero.
	*/
    assert(quantity <= max &&  "Renewable::Renewable: Error creating a Renewable bin");
}

Renewable::~Renewable() {}

void Renewable::returnBin (double amount) {
	/**
	* \warning The amount returned plus the actual quantity of the bin must be less or equal the bins capacity.
	*/
    assert(amount + quantity <= max && "Renewable::returnBin: Error returning Renewable bins"); 
    quantity += amount;
}

double Renewable::getMax() {
	return max;
}
