#include <eosim/utils/beventmap.hpp>
#include <cassert>

using namespace eosim::utils;
using namespace eosim::core;
using namespace std;


BEventMap::BEventMap () {}

BEventMap::~BEventMap () {
	/**
	* \note This operation doesnt delete any BEvents stored.
	*/
}

void BEventMap::put (BEvent* elem) {
	/**
	* \warning The name of the element stored must be unique.
	*/
    assert(elems.find(elem->getName()) == elems.end() && "BEventMap::put: Error inserting a BEvent in a BEventMap");
    elems[elem->getName()] = elem;
}

void BEventMap::remove (string key) {
	/**
	* \warning There must be a BEvent registered whose name is equal to key.
	*/
	assert(elems.find(key) != elems.end() && "BEventMap::remove: Error removing a BEvent from a BEventMap");
    elems.erase(key);
}

BEvent* BEventMap::operator[] (string key) {
	/**
	* \note The use of this operation is either bMap[key] or bMap.operator[](key). If the map is empty or there isnt any element whose name is key, the simulation aborts immediately displaying an error message.
	*/
    /**
	* \warning The map must be not empty and there must be a BEvent whose name is equal to key.
	*/
	BEvent* ret = elems[key];
    assert(ret != 0 && ret->getName() == key && "BEventMap::operator[]: Error indexing in a BEventMap with an unregister key");
    return ret;
}

unsigned int BEventMap::size() {
    return elems.size();
}	

