#include <eosim/utils/entityqueuefifo.hpp>
#include <cassert>

using namespace eosim::core;
using namespace eosim::utils;
using namespace std;
	

EntityQueueFifo::EntityQueueFifo() {}

EntityQueueFifo::~EntityQueueFifo() {
    for (deque<Entity*>::iterator i = elems.begin(); i != elems.end(); i++) {
        delete *i;
    }
}

void EntityQueueFifo::push(Entity* ent) {
    elems.push_back(ent);
}

Entity* EntityQueueFifo::pop() {
	/**
	* \warning The queue is must not be empty.
	*/
    assert(elems.size() > 0 && "EntityQueueFifo::pop: Error removing the first element of a EntityQueueFifo");
    Entity* e = elems.front();
    elems.pop_front();
    return e;
} 

void EntityQueueFifo::remove(unsigned int i) {
	/**
	* \warning i must be within the limits of the queue.
	*/
    assert(i < elems.size() && "EntityQueueFifo::remove: Error removing an Entity from an EntityQueueFifo");
    elems.erase(elems.begin() + i);
}

bool EntityQueueFifo::empty() {
    return elems.empty();
}

Entity* EntityQueueFifo::operator[] (unsigned int i) {
	/**
	* \warning i must be within the limits of the queue.
	*/
    assert(i < elems.size() && "EntityQueueFifo::operator[]: Error indexing in a EntityQueueFifo");
    return elems[i];
}

unsigned int EntityQueueFifo::size() {
    return elems.size();
}

